
# Enabled toolchains
TOOLCHAINS = [
    'iar',
    'mdk',
    'mcux',
    'armgcc',
    'lpcx',
    'xcc',
    'codewarrior'
]


EXCLUDE_DIR_NAME = [
    'log',
    'debug',
    'release'
]
